# PyAcryl2 
[![Build Status](https://travis-ci.com/DPInvaders/pyacryl2.svg?token=s1sqYjTtbQq5zQbpVpA2&branch=master)](https://travis-ci.com/DPInvaders/pyacryl2)
[![Documentation Status](https://readthedocs.org/projects/pyacryl2/badge/?version=latest)](https://pyacryl2.readthedocs.io/en/latest/?badge=latest)

[Acryl](https://acrylplatform.com/ "Acryl Platform") Node API client 

**Full documentation**
https://pyacryl2.readthedocs.io/en/latest/

## Installation

Requirements:
- Python 3.6 and higher
- Packages from `requirements.txt`



From PyPI:

```bash
pip install pyacryl2
```

Or from source:

```bash
python setup.py install
```


## What's included

- [X] Node API client
	- [X] Sync
	- [X] Async
	
- [X] Generators and validators
	- [X] Address data
	- [X] Transactions data

- [ ] Matcher API

- [X] Docs
- [X] Tests

